/* Includes ------------------------------------------------------------------*/
#include "stm32f0xx.h"

/* Private define ------------------------------------------------------------*/
#define GREEN_LED_PIN             GPIO_Pin_9
#define GREEN_LED_PORT            GPIOC
#define BLUE_LED_PIN              GPIO_Pin_8
#define BLUE_LED_PORT             GPIOC
#define USER_BUTTON_PIN           GPIO_Pin_0
#define USER_BUTTON_PORT          GPIOA
#define GREEN_LED_PERIPH_CLOCK    RCC_AHBPeriph_GPIOC
#define BLUE_LED_PERIPH_CLOCK     RCC_AHBPeriph_GPIOC
#define USER_BUTTON_PERIPH_CLOCK  RCC_AHBPeriph_GPIOA

#define USER_BUTTON_IS_PRESSED (USER_BUTTON_PORT->IDR & USER_BUTTON_PIN)

int main(void)
{
	//enable clocking to the GPIO ports
	RCC_AHBPeriphClockCmd(GREEN_LED_PERIPH_CLOCK, ENABLE);
	RCC_AHBPeriphClockCmd(BLUE_LED_PERIPH_CLOCK, ENABLE);
	RCC_AHBPeriphClockCmd(USER_BUTTON_PERIPH_CLOCK, ENABLE);

	//Set up the pins for the LEDs and user button
	GPIO_InitTypeDef	GPIOInit;
	GPIOInit.GPIO_Mode = GPIO_Mode_OUT;
	GPIOInit.GPIO_OType = GPIO_OType_PP;
	GPIOInit.GPIO_Pin = GREEN_LED_PIN;
	GPIOInit.GPIO_PuPd = GPIO_PuPd_NOPULL;
	GPIOInit.GPIO_Speed = GPIO_Speed_Level_3;
	GPIO_Init(GREEN_LED_PORT, &GPIOInit);

	GPIOInit.GPIO_Pin = BLUE_LED_PIN;
	GPIO_Init(BLUE_LED_PORT, &GPIOInit);

	GPIOInit.GPIO_Mode = GPIO_Mode_IN;
	GPIOInit.GPIO_Pin = USER_BUTTON_PIN;
	GPIO_Init(USER_BUTTON_PORT, &GPIOInit);


	//loop forever
	while (1)
	{
		if (USER_BUTTON_IS_PRESSED)
		{
			GREEN_LED_PORT->BSRR = (GREEN_LED_PIN << 16) + BLUE_LED_PIN;
		}
		else
		{
			GREEN_LED_PORT->BSRR = (BLUE_LED_PIN << 16) + GREEN_LED_PIN;
		}
	}
}

#ifdef  USE_FULL_ASSERT

/**
  * @brief  Reports the name of the source file and the source line number
  *   where the assert_param error has occurred.
  * @param  file: pointer to the source file name
  * @param  line: assert_param error line source number
  * @retval None
  */
void assert_failed(uint8_t* file, uint32_t line)
{
  /* User can add his own implementation to report the file name and line number,
     ex: printf("Wrong parameters value: file %s on line %d\r\n", file, line) */

  /* Infinite loop */
  while (1)
  {}
}
#endif
